==> knative-model-6.7.1-sources.jar: io/fabric8/knative/eventing/v1/BrokerListBuilder.java <==
package io.fabric8.knative.eventing.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class BrokerListBuilder extends BrokerListFluentImpl<BrokerListBuilder> implements VisitableBuilder<BrokerList,BrokerListBuilder>{
  public BrokerListBuilder() {
    this(false);
  }
  public BrokerListBuilder(Boolean validationEnabled) {
    this(new BrokerList(), validationEnabled);
  }
  public BrokerListBuilder(BrokerListFluent<?> fluent) {
    this(fluent, false);
  }
  public BrokerListBuilder(BrokerListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new BrokerList(), validationEnabled);
  }
  public BrokerListBuilder(BrokerListFluent<?> fluent,BrokerList instance) {
    this(fluent, instance, false);
  }
  public BrokerListBuilder(BrokerListFluent<?> fluent,BrokerList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
    }
    this.validationEnabled = validationEnabled; 
  }
  public BrokerListBuilder(BrokerList instance) {
    this(instance,false);
  }
  public BrokerListBuilder(BrokerList instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
    }
    this.validationEnabled = validationEnabled; 
  }
  BrokerListFluent<?> fluent;
  Boolean validationEnabled;
  public BrokerList build() {
    BrokerList buildable = new BrokerList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    return buildable;
  }
  
}

==> knative-model-6.8.1-sources.jar: io/fabric8/knative/eventing/v1/BrokerListBuilder.java <==
package io.fabric8.knative.eventing.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class BrokerListBuilder extends BrokerListFluent<BrokerListBuilder> implements VisitableBuilder<BrokerList,BrokerListBuilder>{
  public BrokerListBuilder() {
    this(false);
  }
  public BrokerListBuilder(Boolean validationEnabled) {
    this(new BrokerList(), validationEnabled);
  }
  public BrokerListBuilder(BrokerListFluent<?> fluent) {
    this(fluent, false);
  }
  public BrokerListBuilder(BrokerListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new BrokerList(), validationEnabled);
  }
  public BrokerListBuilder(BrokerListFluent<?> fluent,BrokerList instance) {
    this(fluent, instance, false);
  }
  public BrokerListBuilder(BrokerListFluent<?> fluent,BrokerList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new BrokerList());

    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
    }
    this.validationEnabled = validationEnabled; 
  }
  public BrokerListBuilder(BrokerList instance) {
    this(instance,false);
  }
  public BrokerListBuilder(BrokerList instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new BrokerList());

    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
    }
    this.validationEnabled = validationEnabled; 
  }
  BrokerListFluent<?> fluent;
  Boolean validationEnabled;
  public BrokerList build() {
    BrokerList buildable = new BrokerList(fluent.getApiVersion(),fluent.buildItems(),fluent.getKind(),fluent.getMetadata());
    return buildable;
  }
  
}
